@@ -165,6 +165,24 @@ class DLLIMPORT cbProject : public CompileTargetBase
         /** @return True if the project is using a custom Makefile for compilation, false if not. */
         bool IsMakefileCustom(){ return m_CustomMakefile; }
 
+        /** Allow the specification of specific execution directory if the project use a custom Makefile.
+          * Defaults to the projects base path, if no custom makefile is used.
+          * @param dir The directory the custom Makefile should be executed from.
+          */
+        void SetMakefileExecutionDir(const wxString& dir);
+
+        /** @return The execution directory for the custom Makefile.
+          * Defaults to the projects base path, if no custom makefile is used.
+          */
+        wxString GetMakefileExecutionDir();
+
+        /** @return Either the execution directory for the custom Makefile or
+          * the projects base path.
+          * Defaults to the projects base path, if no custom makefile is used.
+          * Used to unify the call to the function.
+          */
+        wxString GetExecutionDir();
+
         /** Is there a build target (virtual or real) by @c name?
           * @param name The build target's name.
           * @param virtuals_too Include virtual build targets in query.
@@ -630,7 +648,7 @@ class DLLIMPORT cbProject : public CompileTargetBase
           * and than calls base function.
           */
         virtual void SetTitle(const wxString& title);
-        
+
         /** Access the \<Extensions\> XML node of this project
           *
           * This function is for advanced users only. Use at your own risk
@@ -640,7 +658,7 @@ class DLLIMPORT cbProject : public CompileTargetBase
           * @note This function will never return NULL.
           */
         virtual TiXmlNode* GetExtensionsNode();
-        
+
         /** Convenience function (mainly for scripts) to add nodes/attributes
           * under the \<Extensions\> node.
           *
@@ -676,6 +694,7 @@ class DLLIMPORT cbProject : public CompileTargetBase
         wxString CreateUniqueFilename();
         void NotifyPlugins(wxEventType type, const wxString& targetName = wxEmptyString, const wxString& oldTargetName = wxEmptyString);
         void CopyTreeNodeRecursively(wxTreeCtrl* tree, const wxTreeItemId& item, const wxTreeItemId& new_parent);
+        bool VirtualFolderDragged(wxTreeCtrl* tree, wxTreeItemId from, wxTreeItemId to);
 
         // properties
         VirtualBuildTargetsMap m_VirtualTargets;
@@ -685,6 +704,7 @@ class DLLIMPORT cbProject : public CompileTargetBase
         wxString m_DefaultExecuteTarget;
         wxString m_Makefile;
         bool m_CustomMakefile;
+        mutable wxString m_MakefileExecutionDir;
 
         FilesList m_Files;
         wxArrayString m_ExpandedNodes;
@@ -708,7 +728,7 @@ class DLLIMPORT cbProject : public CompileTargetBase
         bool m_ExtendedObjectNamesGeneration;
         wxString m_Notes;
         bool m_AutoShowNotesOnLoad;
-        
+
         // copy of <Extensions> element, in case certain plugins are disabled
         // so that the contents are not lost
         TiXmlElement* m_pExtensionsElement;
