@@ -13,17 +13,15 @@
 #endif
 
 //(*Headers(VirtualBuildTargetsDlg)
-#include <wx/button.h>
 #include <wx/checklst.h>
-#include <wx/dialog.h>
+#include <wx/button.h>
+#include "scrollingdialog.h"
 #include <wx/listbox.h>
-#include <wx/sizer.h>
-#include <wx/statline.h>
 //*)
 
 class cbProject;
 
-class VirtualBuildTargetsDlg: public wxDialog
+class VirtualBuildTargetsDlg: public wxScrollingDialog
 {
 	public:
 
@@ -46,11 +44,11 @@ class VirtualBuildTargetsDlg: public wxDialog
 		void OnUpdateUI(wxUpdateUIEvent& event);
 
 		//(*Declarations(VirtualBuildTargetsDlg)
-		wxListBox* lstAliases;
-		wxButton* btnAdd;
+		wxCheckListBox* lstTargets;
 		wxButton* btnEdit;
 		wxButton* btnRemove;
-		wxCheckListBox* lstTargets;
+		wxButton* btnAdd;
+		wxListBox* lstAliases;
 		//*)
 
         void SetVirtualTarget(const wxString& targetName);
